import shutil

import pytest
from sphinx.testing import path

# this is necessary because Sphinx isn't exposing its fixtures
# https://docs.pytest.org/en/7.1.x/how-to/writing_plugins.html#requiring-loading-plugins-in-a-test-module-or-conftest-file
pytest_plugins = ['sphinx.testing.fixtures']


@pytest.fixture
def rootdir(tmpdir):
    src = path.path(__file__).parent.abspath() / 'roots'
    dst = tmpdir.join('roots')
    shutil.copytree(src, dst)
    roots = path.path(dst)
    print(dst)
    yield roots
    shutil.rmtree(dst)



# file: cli.py
import click


main = click.Group(
    name='Principal Commands',
    help=(
        "Principal commands that are used in ``cli``.\n\n"
        "The section name and description are obtained using the name and "
        "description of the group passed as sources for |CommandCollection|_."
    ),
)


@main.command(help='CMD 1')
def cmd1() -> None:
    print('call cmd 1')


helpers = click.Group(
    name='Helper Commands',
    help="Helper commands for ``cli``.",
)


@helpers.command()
def cmd2() -> None:
    "Helper command that has no option."
    pass


@helpers.command()
@click.option('--user', type=str)
def cmd3(user: str) -> None:
    "Helper command with an option."
    pass


cli = click.CommandCollection(
    name='cli',
    sources=[main, helpers],
    help='Some general info on ``cli``.',
)



# file: cli.py
import click


@click.command()
@click.option('--param', envvar='PARAM', help='A sample option')
@click.option('--another', metavar='[FOO]', help='Another option')
@click.option(
    '--choice',
    help='A sample option with choices',
    type=click.Choice(['Option1', 'Option2']),
)
@click.option(
    '--numeric-choice',
    metavar='<choice>',
    help='A sample option with numeric choices',
    type=click.Choice([1, 2, 3]),
)
@click.option(
    '--flag',
    is_flag=True,
    help='A boolean flag',
)
@click.argument('ARG', envvar='ARG')
def cli(
    param: str,
    another: str,
    choice: str,
    numeric_choice: int,
    flag: bool,
) -> None:
    """A sample command."""
    pass
